@@ -144,6 +144,7 @@ HEADERS = ["Test Name", "Remoting Tech", "Server Version", "Client Version", "Cu
            "Regions/s", "Pixels/s Sent", "Encoding Pixels/s", "Decoding Pixels/s",
            "Application packets in/s", "Application bytes in/s",
            "Application packets out/s", "Application bytes out/s", "mmap bytes/s",
+           "Frame Total Latency", "Client Frame Latency",
            "Video Encoder", "CSC", "CSC Mode", "Scaling",
            ]
 for x in ("client", "server"):
@@ -185,19 +186,19 @@ def find_matching_lines(out, pattern):
             lines.append(line)
     return  lines
 
-def getoutput_lines(cmd, pattern, setup_info):
+def getoutput_lines(cmd, pattern):
     out = getoutput(cmd)
     return  find_matching_lines(out, pattern)
 
-def getoutput_line(cmd, pattern, setup_info):
-    lines = getoutput_lines(cmd, pattern, setup_info)
+def getoutput_line(cmd, pattern):
+    lines = getoutput_lines(cmd, pattern)
     if len(lines)!=1:
         print("WARNING: expected 1 line matching '%s' from %s but found %s" % (pattern, cmd, len(lines)))
         return "not found"
     return  lines[0]
 
 def get_cpu_info():
-    lines = getoutput_lines(["cat", "/proc/cpuinfo"], "model name", "cannot find cpu info")
+    lines = getoutput_lines(["cat", "/proc/cpuinfo"], "model name")
     assert lines, "coult not find 'model name' in '/proc/cpuinfo'"
     cpu0 = lines[0]
     n = len(lines)
@@ -212,15 +213,14 @@ def get_cpu_info():
     print("CPU_INFO=%s" % cpu_info)
     return  cpu_info, n
 
-XORG_VERSION = getoutput_line([config.XORG_BIN, "-version"], "X.Org X Server", "Cannot detect Xorg server version")
+XORG_VERSION = getoutput_line([config.XORG_BIN, "-version"], "X.Org X Server")
 print("XORG_VERSION=%s" % XORG_VERSION)
 CPU_INFO, N_CPUS = get_cpu_info()
 KERNEL_VERSION = getoutput(["uname", "-r"]).replace("\n", "").replace("\r", "")
 PAGE_SIZE = int(getoutput(["getconf", "PAGESIZE"]).replace("\n", "").replace("\r", ""))
 PLATFORM = getoutput(["uname", "-p"]).replace("\n", "").replace("\r", "")
 OPENGL_INFO = getoutput_line(["glxinfo"],
-                             "OpenGL renderer string",
-                             "Cannot detect OpenGL renderer string").split("OpenGL renderer string:")[1].strip()
+                             "OpenGL renderer string").split("OpenGL renderer string:")[1].strip()
 
 SCREEN_SIZE = get_root_size()
 print("screen size=%s" % str(SCREEN_SIZE))
@@ -327,7 +327,7 @@ def compute_stat(prefix, time_total_diff, old_pid_stat, new_pid_stat):
 
 def getiptables_line(chain, pattern, setup_info):
     cmd = config.IPTABLES_CMD + ["-vnL", chain]
-    line = getoutput_line(cmd, pattern, setup_info)
+    line = getoutput_line(cmd, pattern)
     if not line:
         raise Exception("no line found matching %s, make sure you have a rule like: %s" % (pattern, setup_info))
     return line
@@ -355,12 +355,14 @@ def get_iptables_OUTPUT_count():
 
 def measure_client(server_pid, name, cmd, get_stats_cb):
     print("starting client: %s" % cmd)
+    client_process = None
     try:
         client_process = Popen(cmd)
         #give it time to settle down:
         time.sleep(config.SETTLE_TIME)
-        code = client_process.poll()
-        assert code is None, "client failed to start, return code is %s" % code
+        if cmd[0].startswith("python"):
+            code = client_process.poll()
+            assert code is None, "client failed to start, return code is %s" % code
         #clear counters
         initial_stats = get_stats_cb()
         zero_iptables()
@@ -375,8 +377,9 @@ def measure_client(server_pid, name, cmd, get_stats_cb):
             time.sleep(config.COLLECT_STATS_TIME)
             t += config.COLLECT_STATS_TIME
 
-            code = client_process.poll()
-            assert code is None, "client crashed, return code is %s" % code
+            if cmd[0].startswith("python"):
+                code = client_process.poll()
+                assert code is None, "client crashed, return code is %s" % code
 
             stats = get_stats_cb(initial_stats, all_stats)
 
@@ -416,7 +419,9 @@ def measure_client(server_pid, name, cmd, get_stats_cb):
 
 def with_server(start_server_command, stop_server_commands, in_tests, get_stats_cb):
     tests = in_tests[config.STARTING_TEST:config.LIMIT_TESTS]
-    print("going to run %s tests: %s" % (len(tests), [x[0] for x in tests]))
+    print("going to run %s tests:" % len(tests))
+    for test in tests:
+        print(" * %s" % test[0])
     print("*******************************************")
     print("ETA: %s minutes" % int((config.SERVER_SETTLE_TIME+config.DEFAULT_TEST_COMMAND_SETTLE_TIME+config.SETTLE_TIME+config.MEASURE_TIME+1)*len(tests)/60))
     print("*******************************************")
@@ -467,7 +472,7 @@ def with_server(start_server_command, stop_server_commands, in_tests, get_stats_
                     #start the test command:
                     if config.USE_VIRTUALGL:
                         if isinstance(test_command, str):
-                            cmd = config.VGLRUN_BIN + "-d "+os.environ.get("DISPLAY")+" -- "+ test_command
+                            cmd = config.VGLRUN_BIN + " -d "+os.environ.get("DISPLAY")+" -- "+ test_command
                         elif isinstance(test_command, (list, tuple)):
                             cmd = [config.VGLRUN_BIN, "-d", os.environ.get("DISPLAY"), "--"] + list(test_command)
                         else:
@@ -681,9 +686,12 @@ def xpra_get_stats(initial_stats=None, all_stats=[]):
     add("", avg, "Encoding Pixels/s",               ["client.encoding.pixels_encoded_per_second", "encoding.pixels_encoded_per_second", "pixels_encoded_per_second"])
     add("", avg, "Decoding Pixels/s",               ["client.encoding.pixels_decoded_per_second", "encoding.pixels_decoded_per_second", "pixels_decoded_per_second"])
 
+    add("", avg, "Frame Total Latency",             ["client.damage.frame-total-latency"])
+    add("", avg, "Client Frame Latency",            ["client.damage.client-latency"])
+
     for prefix, op in (("Min", min), ("Max", max), ("Avg", avg)):
         add(prefix, op, "Batch Delay (ms)",         ["client.batch.delay.%s", "batch.delay.%s", "batch_delay.%s", "%s_batch_delay"])
-        add(prefix, op, "Actual Batch Delay (ms)",  ["client.window.?[\d+].batch.actual_delays.%s", "client.batch.actual_delay.%s", "batch.actual_delay.%s"])
+        add(prefix, op, "Actual Batch Delay (ms)",  ["client.window.?[\\d+].batch.actual_delays.%s", "client.batch.actual_delay.%s", "batch.actual_delay.%s"])
         add(prefix, op, "Client Latency (ms)",      ["client.connection.client.latency.%s", "client.latency.%s", "client_latency.%s", "%s_client_latency"])
         add(prefix, op, "Client Ping Latency (ms)", ["client.connection.client.ping_latency.%s", "client.ping_latency.%s", "client_ping_latency.%s"])
         add(prefix, op, "Server Ping Latency (ms)", ["client.connection.server.ping_latency.%s", "server.ping_latency.%s", "server_ping_latency.%s", "server_latency.%s", "%s_server_latency"])
@@ -730,6 +738,7 @@ def get_xpra_start_server_command():
     cmd += ["start", ":%s" % config.DISPLAY_NO]
     return cmd
 
+
 def test_xpra():
     print("")
     print("*********************************************************")
@@ -742,96 +751,109 @@ def test_xpra():
             shaping_options = [config.NO_SHAPING]
         for down,up,latency in shaping_options:
             for x11_test_command in config.X11_TEST_COMMANDS:
-                for encoding in config.XPRA_TEST_ENCODINGS:
-                    if XPRA_VERSION_NO>=[0, 10]:
-                        opengl_options = config.XPRA_OPENGL_OPTIONS.get(encoding, [True])
-                    elif XPRA_VERSION_NO>=[0, 9]:
-                        opengl_options = config.XPRA_OPENGL_OPTIONS.get(encoding, [False])
-                    else:
-                        opengl_options = [False]
-                    for opengl in opengl_options:
-                        quality_options = config.XPRA_ENCODING_QUALITY_OPTIONS.get(encoding, [-1])
-                        for quality in quality_options:
-                            speed_options = config.XPRA_ENCODING_SPEED_OPTIONS.get(encoding, [-1])
-                            for speed in speed_options:
-                                for speaker in XPRA_SPEAKER_OPTIONS:
-                                    for mic in XPRA_MICROPHONE_OPTIONS:
-                                        comp_options = [None]
-                                        if XPRA_VERSION_NO>=[0, 13]:
-                                            comp_options = config.XPRA_COMPRESSORS_OPTIONS
-                                        for comp in comp_options:
-                                            comp_level_options = config.XPRA_COMPRESSION_LEVEL_OPTIONS
-                                            for compression in comp_level_options:
-                                                packet_encoders_options = [None]
-                                                if XPRA_VERSION_NO>=[0, 14]:
-                                                    packet_encoders_options = config.XPRA_PACKET_ENCODERS_OPTIONS
-                                                for packet_encoders in packet_encoders_options:
-                                                    cmd = trickle_command(down, up, latency)
-                                                    cmd += [XPRA_BIN, "attach"]
-                                                    if connect_option=="ssh":
-                                                        cmd.append("ssh:%s:%s" % (config.IP, config.DISPLAY_NO))
-                                                    elif connect_option=="tcp":
-                                                        cmd.append("tcp:%s:%s" % (config.IP, config.PORT))
-                                                    else:
-                                                        cmd.append(":%s" % (config.DISPLAY_NO))
-                                                    if XPRA_VERSION_NO>=[0, 15]:
-                                                        cmd.append("--readonly=yes")
-                                                    else:
-                                                        cmd.append("--readonly")
-                                                    cmd += get_auth_args(False)
-                                                    if packet_encoders:
-                                                        cmd += ["--packet-encoders=%s" % packet_encoders]
-                                                    if comp:
-                                                        cmd += ["--compressors=%s" % comp]
-                                                    if compression is not None:
-                                                        cmd += ["-z", str(compression)]
-                                                    if XPRA_VERSION_NO>=[0, 3]:
-                                                        cmd.append("--enable-pings")
-                                                        cmd.append("--no-clipboard")
-                                                    if XPRA_VERSION_NO>=[0, 5]:
-                                                        cmd.append("--no-bell")
-                                                        cmd.append("--no-cursors")
-                                                        cmd.append("--no-notifications")
-                                                    if XPRA_VERSION_NO>=[0, 12]:
-                                                        if config.XPRA_MDNS:
-                                                            cmd.append("--mdns")
+                command_name = get_command_name(x11_test_command)
+                for client_type in config.XPRA_CLIENT_TYPES:
+                    if client_type=="html5":
+                        assert not config.XPRA_USE_PASSWORD
+                        if connect_option=="unix-domain":
+                            continue
+                        for browser_cmd in config.XPRA_HTML5_BROWSERS:
+                            cmd = browser_cmd + ["http://localhost:%i/" % (config.PORT)]
+                            test_name = "%s : %s" % (browser_cmd[0], command_name)
+                            tests.append(
+                                (
+                                    test_name, "xpra", XPRA_VERSION, XPRA_VERSION,
+                                    "all", 0, 0,
+                                    "n/a", "n/a", encryption, connect_option,
+                                    (down,up,latency), x11_test_command, cmd,
+                                    )
+                                )
+                        continue
+
+                    #python client has more options:
+                    encodings = config.XPRA_TEST_ENCODINGS
+                    for encoding in encodings:
+                        for opengl in config.XPRA_OPENGL_OPTIONS.get(encoding, [True]):
+                            quality_options = config.XPRA_ENCODING_QUALITY_OPTIONS.get(encoding, [-1])
+                            for quality in quality_options:
+                                speed_options = config.XPRA_ENCODING_SPEED_OPTIONS.get(encoding, [-1])
+                                for speed in speed_options:
+                                    for speaker in XPRA_SPEAKER_OPTIONS:
+                                        for mic in XPRA_MICROPHONE_OPTIONS:
+                                            for comp in config.XPRA_COMPRESSORS_OPTIONS:
+                                                for compression in config.XPRA_COMPRESSION_LEVEL_OPTIONS:
+                                                    for packet_encoders in config.XPRA_PACKET_ENCODERS_OPTIONS:
+                                                        test_name = "(%s - %s - %s - %s - via %s)" % \
+                                                            (command_name, compression, encryption,
+                                                             trickle_str(down, up, latency), connect_option)
+                                                        cmd = trickle_command(down, up, latency)
+                                                        cmd += [client_type, XPRA_BIN, "attach"]
+                                                        if connect_option=="ssh":
+                                                            cmd.append("ssh:%s:%s" % (config.IP, config.DISPLAY_NO))
+                                                        elif connect_option=="tcp":
+                                                            cmd.append("tcp:%s:%s" % (config.IP, config.PORT))
                                                         else:
-                                                            cmd.append("--no-mdns")
-                                                    if XPRA_VERSION_NO>=[0, 8] and encryption:
-                                                        cmd.append("--encryption=%s" % encryption)
-                                                    if speed>=0:
-                                                        cmd.append("--speed=%s" % speed)
-                                                    if quality>=0:
-                                                        if XPRA_VERSION_NO>=[0, 7]:
-                                                            cmd.append("--quality=%s" % quality)
+                                                            cmd.append(":%s" % (config.DISPLAY_NO))
+                                                        if XPRA_VERSION_NO>=[0, 15]:
+                                                            cmd.append("--readonly=yes")
                                                         else:
-                                                            cmd.append("--jpeg-quality=%s" % quality)
-                                                        name = "%s-%s" % (encoding, quality)
-                                                    else:
-                                                        name = encoding
-                                                    if speaker is None:
-                                                        if XPRA_VERSION_NO>=[0, 8]:
-                                                            cmd.append("--no-speaker")
-                                                    else:
-                                                        cmd.append("--speaker-codec=%s" % speaker)
-                                                    if mic is None:
-                                                        if XPRA_VERSION_NO>=[0, 8]:
-                                                            cmd.append("--no-microphone")
-                                                    else:
-                                                        cmd.append("--microphone-codec=%s" % mic)
-                                                    if encoding!="mmap":
-                                                        cmd.append("--no-mmap")
-                                                        cmd.append("--encoding=%s" % encoding)
-                                                    if XPRA_VERSION_NO>=[0, 9]:
-                                                        cmd.append("--opengl=%s" % opengl)
-                                                    command_name = get_command_name(x11_test_command)
-                                                    test_name = "%s (%s - %s - %s - %s - via %s)" % \
-                                                        (name, command_name, compression, encryption,
-                                                         trickle_str(down, up, latency), connect_option)
-                                                    tests.append((test_name, "xpra", XPRA_VERSION, XPRA_VERSION, \
-                                                                  encoding, quality, speed,
-                                                                  opengl, compression, encryption, connect_option, \
-                                                                  (down,up,latency), x11_test_command, cmd))
+                                                            cmd.append("--readonly")
+                                                        cmd += get_auth_args(False)
+                                                        if packet_encoders:
+                                                            cmd += ["--packet-encoders=%s" % packet_encoders]
+                                                        if comp:
+                                                            cmd += ["--compressors=%s" % comp]
+                                                        if compression is not None:
+                                                            cmd += ["-z", str(compression)]
+                                                        if XPRA_VERSION_NO>=[0, 3]:
+                                                            cmd.append("--enable-pings")
+                                                            cmd.append("--no-clipboard")
+                                                        if XPRA_VERSION_NO>=[0, 5]:
+                                                            cmd.append("--no-bell")
+                                                            cmd.append("--no-cursors")
+                                                            cmd.append("--no-notifications")
+                                                        if XPRA_VERSION_NO>=[0, 12]:
+                                                            if config.XPRA_MDNS:
+                                                                cmd.append("--mdns")
+                                                            else:
+                                                                cmd.append("--no-mdns")
+                                                        if XPRA_VERSION_NO>=[0, 8] and encryption:
+                                                            cmd.append("--encryption=%s" % encryption)
+                                                        if speed>=0:
+                                                            cmd.append("--speed=%s" % speed)
+                                                        if quality>=0:
+                                                            if XPRA_VERSION_NO>=[0, 7]:
+                                                                cmd.append("--quality=%s" % quality)
+                                                            else:
+                                                                cmd.append("--jpeg-quality=%s" % quality)
+                                                            name = "%s-%s" % (encoding, quality)
+                                                        else:
+                                                            name = encoding
+                                                        if speaker is None:
+                                                            if XPRA_VERSION_NO>=[0, 8]:
+                                                                cmd.append("--no-speaker")
+                                                        else:
+                                                            cmd.append("--speaker-codec=%s" % speaker)
+                                                        if mic is None:
+                                                            if XPRA_VERSION_NO>=[0, 8]:
+                                                                cmd.append("--no-microphone")
+                                                        else:
+                                                            cmd.append("--microphone-codec=%s" % mic)
+                                                        if encoding!="mmap":
+                                                            cmd.append("--no-mmap")
+                                                            cmd.append("--encoding=%s" % encoding)
+                                                        if XPRA_VERSION_NO>=[0, 9]:
+                                                            cmd.append("--opengl=%s" % opengl)
+
+                                                        full_test_name = "%6s %s" % (name, test_name)
+                                                        tests.append(
+                                                            (
+                                                                full_test_name, "xpra", XPRA_VERSION, XPRA_VERSION,
+                                                                encoding, quality, speed,
+                                                                opengl, compression, encryption, connect_option,
+                                                                (down,up,latency), x11_test_command, cmd,
+                                                                )
+                                                            )
     return with_server(get_xpra_start_server_command(), XPRA_SERVER_STOP_COMMANDS, tests, xpra_get_stats)
 
 def get_x11_client_window_info(display, *app_name_strings):
