@@ -102,6 +102,8 @@ metrics = {"Regions/s": 1,
            "Application bytes in/s": 1,
            "Application packets out/s": 1,
            "Application bytes out/s": 1,
+           "Frame Total Latency": 1,
+           "Client Frame Latency": 1,
            "client user cpu_pct": 1,
            "client system cpu pct": 1,
            "client number of threads": 1,
@@ -166,7 +168,7 @@ def accumulate_values(file_name, rep, param, uniqueId):
         else:
             app = get_value(row, "Test Command")
             if (not app in apps):
-                print "Application: " + app + " not defined."
+                print("Application: " + app + " not defined.")
                 exit()
 
             if (apps[app] == 1):
@@ -179,7 +181,7 @@ def accumulate_values(file_name, rep, param, uniqueId):
                     encoding = 'vp8'
 
                 if (not encoding in encodings):
-                    print "Encoding: " + encoding + " not defined."
+                    print("Encoding: " + encoding + " not defined.")
                     exit()
 
                 if (encodings[encoding] == 1):
