@@ -12,7 +12,7 @@ DO_ZIP=${DO_ZIP:-0}
 DO_INSTALLER=${DO_INSTALLER:-1}
 DO_TESTS=${DO_TESTS:-1}
 DO_VERPATCH=${DO_VERPATCH:-1}
-DO_SERVICE=${DO_SERVICE:-1}
+DO_SERVICE=${DO_SERVICE:-0}
 CLIENT_ONLY=${CLIENT_ONLY:-0}
 RUN_INSTALLER=${RUN_INSTALLER:-1}
 DO_MSI=${DO_MSI:-0}
@@ -23,16 +23,21 @@ BUNDLE_OPENSSL=${BUNDLE_OPENSSL:-1}
 ZIP_MODULES=${ZIP_MODULES:-1}
 
 PYTHON=${PYTHON:-python3}
+export PYTHONIOENCODING=UTF-8
 
 KEY_FILE="E:\\xpra.pfx"
 DIST="./dist"
-BUILD_OPTIONS="--without-enc_x265 --without-cuda_rebuild"
+BUILD_OPTIONS="${BUILD_OPTIONS} --without-enc_x265 --without-cuda_rebuild"
 
 if [ "${CLIENT_ONLY}" == "1" ]; then
 	DO_TESTS="0"
 	DO_SERVICE="0"
+	BUILD_OPTIONS="${BUILD_OPTIONS} --without-enc_x264 --without-nvenc --without-nvfbc"
 	shift
 fi
+if [ "${DO_CUDA}" == "0" ]; then
+	BUILD_OPTIONS="${BUILD_OPTIONS} --without-nvjpeg --without-nvenc --without-nvfbc"
+fi
 
 ################################################################################
 # get paths and compilation options:
@@ -133,6 +138,7 @@ if [ "${DO_CLEAN}" == "1" ]; then
 	find xpra/ -name "*.pyd" -exec rm -f {} \;
 	#python3:
 	find xpra/ -name "*-cpython-*dll" -exec rm -f {} \;
+	find xpra/ -name "*.cp*-mingw*.pyd" -exec rm -f {} \;
 	CLEAN_LOG="clean.log"
 	${PYTHON} ./setup.py clean >& "${CLEAN_LOG}"
 	if [ "$?" != "0" ]; then
@@ -258,26 +264,53 @@ rm -fr "${DIST}/lib/comtypes/gen"
 pushd ${DIST} > /dev/null
 #why is it shipping those files??
 find lib/ -name "*dll.a" -exec rm {} \;
+if [ "${BITS}" == "32" ]; then
+	#no idea why this is needed on x86 only
+	cp lib/libgdk-*dll ./
+	cp lib/libepoxy*dll ./
+fi
 #only keep the actual loaders, not all the other crap cx_Freeze put there:
+#but keep librsvg
+mv lib/gdk-pixbuf-2.0/2.10.0/loaders/librsvg* ./
 mkdir lib/gdk-pixbuf-2.0/2.10.0/loaders.tmp
 mv lib/gdk-pixbuf-2.0/2.10.0/loaders/libpixbufloader-*.dll lib/gdk-pixbuf-2.0/2.10.0/loaders.tmp/
 rm -fr lib/gdk-pixbuf-2.0/2.10.0/loaders
 mv lib/gdk-pixbuf-2.0/2.10.0/loaders.tmp lib/gdk-pixbuf-2.0/2.10.0/loaders
 #move libs that are likely to be common to the lib dir:
 for prefix in lib avcodec avformat avutil swscale swresample zlib1 xvidcore; do
-	find lib/Xpra -name "${prefix}*dll" -exec mv {} ./lib/ \;
-done
-for x in openblas gfortran quadmath; do
-	mv -f ./lib/numpy/core/lib$x*.dll ./lib/
-	mv -f ./lib/numpy/linalg/lib$x*.dll ./lib/
+	#just in case they were not included yet by cx_Freeze:
+	cp $MINGW_PREFIX/bin/${prefix}*.dll ./lib/
+	find lib/Xpra -name "${prefix}*.dll" -exec mv {} ./lib/ \;
 done
+if [ "${CLIENT_ONLY}" ]; then
+	rm -fr ./lib/numpy
+else
+	for x in openblas gfortran quadmath; do
+		mv -f ./lib/numpy/core/lib$x*.dll ./lib/
+		mv -f ./lib/numpy/linalg/lib$x*.dll ./lib/
+	done
+	#trim tests from numpy
+	pushd ./lib/numpy > /dev/null
+	rm -fr ./f2py/docs ./tests ./doc
+	for x in core distutils f2py lib linalg ma matrixlib oldnumeric polynomial random testing compat fft; do
+		rm -fr ./$x/tests
+	done
+	popd > /dev/null
+fi
+rm lib/libx265*.dll
 mv lib/nacl/libsodium*dll ./lib/
-#gstreamer uses its own lib dir, so this does not belong in the root:
-mv ./libgst*.dll ./lib/gstreamer-1.0/
+#start my moving everything out:
+mv ./lib/gstreamer-1.0/* ./lib/
+#this does not belong in the root:
+mv ./lib/libgst*.dll ./lib/gstreamer-1.0/
 #but the main gstreamer lib does:
 mv ./lib/gstreamer-1.0/libgstreamer*.dll ./lib/
 #and the gstreamer support libraries look like plugins but those are actual DLLs:
 mv ./lib/gstreamer-1.0/libgst*-1.0-*.dll ./lib/
+GST_DLLS="audioconvert audioparsers audiorate audioresample audiotestsrc cutter directsound directsoundsrc faac faad flac isomp4 lame matroska mpg123 ogg opus opusparse speex volume vorbis wasapi wavenc wavpack wavparse"
+for x in ${GST_DLLS}; do
+	cp $MINGW_PREFIX/lib/gstreamer-1.0/libgst$x*.dll ./lib/gstreamer-1.0/
+done
 if [ "${PYTHON_MAJOR_VERSION}" == "3" ]; then
 	#move most DLLs to /lib
 	mv *dll lib/
@@ -289,6 +322,16 @@ else
 	mv lib/*dll ./
 	pushd . > /dev/null
 fi
+#cx_Freeze forgets these!?
+ESSENTIALS="atk gtk intl glib pcre winpthread brotlienc croco pdfium lz4 gthread"
+#include avcodec by default (lots of dependencies):
+ESSENTIALS="${ESSENTIALS} aom celt0 dav1d gsm iconv lzma mfx mp3lame opencore openjp2 opus speex theoradec theoraenc vorbis vpx vulkan webp x264 x265"
+if [ "${PYTHON_MAJOR_VERSION}" == "2" ]; then
+	ESSENTIALS="${ESSENTIALS} pyglib gtkglext"
+fi
+for x in ${ESSENTIALS}; do
+	cp $MINGW_PREFIX/bin/lib$x*.dll ./
+done
 #remove all the pointless duplication:
 for x in `ls *dll`; do
 	find ./ -mindepth 2 -name "${x}" -exec rm {} \;
@@ -304,13 +347,6 @@ popd > /dev/null
 pushd ${DIST}/lib > /dev/null
 #remove test bits we don't need:
 rm -fr ./future/backports/test ./comtypes/test/ ./ctypes/macholib/fetch_macholib* ./distutils/tests ./distutils/command ./enum/doc ./websocket/tests ./email/test/
-#trim tests from numpy
-pushd numpy > /dev/null
-rm -fr ./f2py/docs ./tests ./doc
-for x in core distutils f2py lib linalg ma matrixlib oldnumeric polynomial random testing compat fft; do
-	rm -fr ./$x/tests
-done
-popd > /dev/null
 #remove source:
 find xpra -name "*.pyx" -exec rm {} \;
 find xpra -name "*.c" -exec rm {} \;
@@ -340,6 +376,12 @@ if [ "${ZIP_MODULES}" == "1" ]; then
 			logging queue urllib xml xmlrpc pyasn1_modules concurrent pynvml collections > /dev/null
 fi
 popd > /dev/null
+#remove empty icon directories
+for i in `seq 4`; do
+	find dist/share/icons -type d -exec rmdir {} \; 2> /dev/null
+done
+rm -fr dist/share/xml
+#leave ./dist
 
 
 echo "* Generating gdk pixbuf loaders.cache"
