@@ -62,3 +62,8 @@ echo "for printing support, install libpdfium"
 echo "by downloading the plain x64 pdfium binary from"
 echo "https://github.com/bblanchon/pdfium-binaries"
 echo "and place the `pdfium.dll` in '$MINGW_PREFIX/bin'"
+
+echo
+echo "to support NVIDIA hardware accelerated encoders NVENC and NVJPEG,"
+echo "install their headers and libraries"
+echo "then create a pkgconfig file so the build system will detect them"
