@@ -478,7 +478,7 @@ class ClientWindowBase(ClientWidgetBase):
             geomlog("intpair(%s)=%s", a, v)
             if v:
                 v1, v2 = v
-                if a==b"maximum-size" and v1>=32000 and v2>=32000 and WIN32:
+                if a==b"maximum-size" and v1>=16384 and v2>=16384 and WIN32:
                     #causes problems, see #2714
                     continue
                 sv1 = client.sx(v1)
@@ -692,6 +692,10 @@ class ClientWindowBase(ClientWidgetBase):
                 self.pending_refresh.append((x, y, width, height))
             if options.intget("flush", 0)==0:
                 callbacks.append(self.after_draw_refresh)
+        if coding=="void":
+            from xpra.client.window_backing_base import fire_paint_callbacks
+            fire_paint_callbacks(callbacks)
+            return
         backing.draw_region(x, y, width, height, coding, img_data, rowstride, options, callbacks)
 
     def after_draw_refresh(self, success, message=""):
