@@ -1,29 +1,24 @@
 # This file is part of Xpra.
 # Copyright (C) 2011 Serviware (Arthur Huillet, <ahuillet@serviware.com>)
-# Copyright (C) 2010-2018 Antoine Martin <antoine@devloop.org.uk>
+# Copyright (C) 2010-2019 Antoine Martin <antoine@xpra.org>
 # Copyright (C) 2008, 2010 Nathaniel Smith <njs@pobox.com>
 # Xpra is released under the terms of the GNU GPL v2, or, at your option, any
 # later version. See the file COPYING for details.
 
-import gtk
-from gtk import gdk
+from collections import namedtuple
+import gtk          #@UnresolvedImport
+from gtk import gdk #@UnresolvedImport
 
+from xpra.client.gtk_base.gtk_client_window_base import GTKClientWindowBase, HAS_X11_BINDINGS
+from xpra.gtk_common.gtk_util import WINDOW_NAME_TO_HINT, BUTTON_MASK
+from xpra.gtk_common.gobject_util import one_arg_signal
+from xpra.util import envbool
 from xpra.log import Logger
+
 log = Logger("window")
 statelog = Logger("state")
 eventslog = Logger("events")
-workspacelog = Logger("workspace")
-grablog = Logger("grab")
-mouselog = Logger("mouse")
-draglog = Logger("dragndrop")
-
-
-from collections import namedtuple
-from xpra.client.gtk_base.gtk_client_window_base import GTKClientWindowBase, HAS_X11_BINDINGS
-from xpra.gtk_common.gtk_util import WINDOW_NAME_TO_HINT, WINDOW_EVENT_MASK, BUTTON_MASK
-from xpra.gtk_common.gobject_util import one_arg_signal
-from xpra.util import envbool
-
+drawlog = Logger("draw")
 
 FORCE_IMMEDIATE_PAINT = envbool("XPRA_FORCE_IMMEDIATE_PAINT", False)
 
@@ -53,12 +48,7 @@ class GTK2WindowBase(GTKClientWindowBase):
     #add GTK focus workaround so we will get focus events
     #even when we grab the keyboard:
     __common_gsignals__ = GTKClientWindowBase.__common_gsignals__
-    __common_gsignals__.update({
-                                "xpra-focus-out-event"  : one_arg_signal,
-                                "xpra-focus-in-event"   : one_arg_signal,
-                                })
 
-    WINDOW_EVENT_MASK   = WINDOW_EVENT_MASK
     OR_TYPE_HINTS       = GTK2_OR_TYPE_HINTS
     NAME_TO_HINT        = WINDOW_NAME_TO_HINT
     BUTTON_MASK         = BUTTON_MASK
@@ -69,6 +59,7 @@ class GTK2WindowBase(GTKClientWindowBase):
     WINDOW_STATE_ABOVE      = gdk.WINDOW_STATE_ABOVE
     WINDOW_STATE_BELOW      = gdk.WINDOW_STATE_BELOW
     WINDOW_STATE_STICKY     = gdk.WINDOW_STATE_STICKY
+    WINDOW_STATE_FOCUSED    = 0 #does not exist in pygtk?
 
 
     def do_init_window(self, window_type=gtk.WINDOW_TOPLEVEL):
@@ -77,17 +68,10 @@ class GTK2WindowBase(GTKClientWindowBase):
         # see: https://bugs.kde.org/show_bug.cgi?id=274485
         self.set_data("_kde_no_window_grab", 1)
 
+    def init_drawing_area(self):
+        GTKClientWindowBase.init_drawing_area(self)
+        self.drawing_area.connect("expose-event", self.do_drawing_area_expose_event)
 
-    def enable_alpha(self):
-        screen = self.get_screen()
-        rgba = screen.get_rgba_colormap()
-        statelog("enable_alpha() rgba colormap=%s", rgba)
-        if rgba is None:
-            log.error("Error: cannot handle window transparency, no RGBA colormap", exc_info=True)
-            return False
-        statelog("enable_alpha() using rgba colormap %s for wid %s", rgba, self._id)
-        self.set_colormap(rgba)
-        return True
 
     def xget_u32_property(self, target, name):
         try:
@@ -104,10 +88,10 @@ class GTK2WindowBase(GTKClientWindowBase):
     def is_mapped(self):
         return self.window is not None and self.window.is_visible()
 
-    def get_window_geometry(self):
+    def get_drawing_area_geometry(self):
         gdkwindow = self.get_window()
         x, y = gdkwindow.get_origin()
-        _, _, w, h, _ = gdkwindow.get_geometry()
+        w, h = gdkwindow.get_geometry()[2:4]
         return x, y, w, h
 
     def apply_geometry_hints(self, hints):
@@ -116,8 +100,12 @@ class GTK2WindowBase(GTKClientWindowBase):
 
     ######################################################################
 
-    def queue_draw(self, x, y, width, height):
-        window = self.get_window()
+    def queue_draw_area(self, x, y, width, height):
+        if self.drawing_area:
+            window = self.drawing_area.get_window()
+        else:
+            window = self.get_window()
+        drawlog("queue_draw_area%s window=%s, window offset=%s", (x, y, width, height), window, self.window_offset)
         if not window:
             log.warn("Warning: ignoring draw packet,")
             log.warn(" received for a window which is not realized yet or gone already")
@@ -131,17 +119,24 @@ class GTK2WindowBase(GTKClientWindowBase):
             event = DrawEvent(area=rect)
             self.do_expose_event(event)
 
+    def do_drawing_area_expose_event(self, drawing_area, event):
+        self.do_expose_event(event)
+
     def do_expose_event(self, event):
         #cannot use self
         eventslog("do_expose_event(%s) area=%s", event, event.area)
         backing = self._backing
         if not (self.flags() & gtk.MAPPED) or backing is None:
             return
-        w,h = self.window.get_size()
+        if self.drawing_area:
+            window = self.drawing_area.get_window()
+        else:
+            window = self.get_window()
+        w,h = window.get_size()
         if w>=32768 or h>=32768:
             log.error("cannot paint on window which is too large: %sx%s !", w, h)
             return
-        context = self.window.cairo_create()
+        context = window.cairo_create()
         context.rectangle(event.area)
         context.clip()
         self.paint_backing_offset_border(backing, context)
