@@ -138,9 +138,11 @@ class ConfirmDialogWindow(object):
 def show_confirm_dialog(argv):
     from xpra.platform.gui import ready as gui_ready
     from xpra.gtk_common.quit import gtk_main_quit_on_fatal_exceptions_enable
-    from xpra.platform.gui import init as gui_init
+    from xpra.platform.gui import init as gui_init, set_default_icon
 
+    set_default_icon("information.png")
     gui_init()
+
     gtk_main_quit_on_fatal_exceptions_enable()
 
     log("show_confirm_dialog(%s)", argv)
