@@ -82,6 +82,9 @@ class AnimatedColorWindow(gtk.Window):
 
 
 def main():
+    from xpra.platform.gui import init, set_default_icon
+    set_default_icon("encoding.png")
+    init()
     import signal
     def signal_handler(*_args):
         gtk.main_quit()
