@@ -18,6 +18,7 @@ class TransparentWindow(gtk.Window):
         self.set_position(WIN_POS_CENTER)
         self.set_default_size(320, 320)
         screen = self.get_screen()
+        self.set_title("Window Transparency")
         visual = screen.get_rgba_visual()
         if is_gtk3():
             if visual and screen.is_composited():
@@ -64,6 +65,9 @@ class TransparentWindow(gtk.Window):
         cr.stroke()
 
 def main():
+    from xpra.platform.gui import init, set_default_icon
+    set_default_icon("encoding.png")
+    init()
     import signal
     def signal_handler(*_args):
         gtk.main_quit()
