@@ -640,12 +640,13 @@ class GTKXpraClient(GObjectXpraClient, UIXpraClient):
 
 
     def _add_statusicon_tray(self, tray_list):
-        #add gtk.StatusIcon tray:
-        try:
-            from xpra.client.gtk_base.statusicon_tray import GTKStatusIconTray
-            tray_list.append(GTKStatusIconTray)
-        except Exception as e:
-            log.warn("failed to load StatusIcon tray: %s" % e)
+        #add Gtk.StatusIcon tray, but not under wayland:
+        if not is_Wayland():
+            try:
+                from xpra.client.gtk_base.statusicon_tray import GTKStatusIconTray
+                tray_list.append(GTKStatusIconTray)
+            except Exception as e:
+                log.warn("failed to load StatusIcon tray: %s" % e)
         return tray_list
 
     def get_tray_classes(self):
@@ -763,6 +764,8 @@ class GTKXpraClient(GObjectXpraClient, UIXpraClient):
 
 
     def has_transparency(self):
+        if not envbool("XPRA_ALPHA", True):
+            return False
         screen = screen_get_default()
         if screen is None:
             return is_Wayland()
