@@ -8,7 +8,7 @@
 import os.path
 import sys
 
-from xpra.platform.gui import init as gui_init
+from xpra.platform.gui import init as gui_init, force_focus
 from xpra.gtk_common.gtk_util import (
     gtk_main, add_close_accel, scaled_image, pixbuf_new_from_file,
     window_defaults, WIN_POS_CENTER,
@@ -38,7 +38,7 @@ class UpdateStatusWindow(object):
     def __init__(self):
         self.window = gtk.Window()
         window_defaults(self.window)
-        self.window.connect("destroy", self.close)
+        self.window.connect("delete-event", self.close)
         self.window.set_default_size(400, 200)
         self.window.set_title("Xpra Version Check")
 
@@ -112,8 +112,11 @@ class UpdateStatusWindow(object):
 
     def show(self):
         log("show()")
-        self.window.show()
-        self.window.present()
+        def show():
+            force_focus()
+            self.window.show()
+            self.window.present()
+        glib.idle_add(show)
 
     def hide(self):
         log("hide()")
@@ -122,6 +125,7 @@ class UpdateStatusWindow(object):
     def close(self, *args):
         log("close%s", args)
         self.hide()
+        return True
 
     def destroy(self, *args):
         log("destroy%s", args)
