@@ -9,13 +9,15 @@
 import os
 from threading import RLock
 
-import pycuda               #@UnresolvedImport
-from pycuda import driver   #@UnresolvedImport
-
+from xpra.codecs.nv_util import numpy_import_lock
 from xpra.util import engs, print_nested_dict, envbool, envint, csv
 from xpra.os_util import monotonic_time, bytestostr, PYTHON2
 from xpra.log import Logger
 
+with numpy_import_lock:
+    import pycuda               #@UnresolvedImport
+    from pycuda import driver   #@UnresolvedImport
+
 log = Logger("cuda")
 
 IGNORE_BLACKLIST = envbool("XPRA_CUDA_IGNORE_BLACKLIST", False)
