@@ -1,14 +1,15 @@
 # This file is part of Xpra.
-# Copyright (C) 2014-2017 Antoine Martin <antoine@devloop.org.uk>
+# Copyright (C) 2014-2019 Antoine Martin <antoine@xpra.org>
 # Xpra is released under the terms of the GNU GPL v2, or, at your option, any
 # later version. See the file COPYING for details.
 
-from xpra.log import Logger
-log = Logger("encoder", "proxy")
+from collections import deque
 
 from xpra.codecs.image_wrapper import ImageWrapper
 from xpra.os_util import memoryview_to_bytes, monotonic_time
-from collections import deque
+from xpra.log import Logger
+
+log = Logger("encoder", "proxy")
 
 
 def get_version():
@@ -36,7 +37,7 @@ class Encoder(object):
         the raw pixels and the metadata that goes with it.
     """
 
-    def init_context(self, width, height, src_format, dst_formats, encoding, quality, speed, scaling, options):
+    def init_context(self, width, height, src_format, dst_formats, encoding, quality, speed, scaling, _options):
         self.encoding = encoding
         self.width = width
         self.height = height
@@ -50,6 +51,9 @@ class Encoder(object):
         self.time = 0
         self.first_frame_timestamp = 0
 
+    def is_ready(self):
+        return True
+
     def get_info(self):             #@DuplicatedSignature
         info = get_info()
         if self.src_format is None:
@@ -116,7 +120,7 @@ class Encoder(object):
         self.time = 0
         self.first_frame_timestamp = 0
 
-    def compress_image(self, image, quality=-1, speed=-1, options={}):
+    def compress_image(self, image, quality=-1, speed=-1, options=None):
         log("compress_image(%s, %s)", image, options)
         #pass the pixels as they are
         assert image.get_planes()==ImageWrapper.PACKED, "invalid number of planes: %s" % image.get_planes()
@@ -130,7 +134,7 @@ class Encoder(object):
                 "frame"     : self.frames,
                 "pts"       : image.get_timestamp()-self.first_frame_timestamp,
                 #pass-through encoder options:
-                "options"   : options,
+                "options"   : options or {},
                 #redundant metadata:
                 #"width"     : image.get_width(),
                 #"height"    : image.get_height(),
