@@ -1,5 +1,5 @@
 # This file is part of Xpra.
-# Copyright (C) 2010-2016 Antoine Martin <antoine@devloop.org.uk>
+# Copyright (C) 2010-2016 Antoine Martin <antoine@xpra.org>
 # Xpra is released under the terms of the GNU GPL v2, or, at your option, any
 # later version. See the file COPYING for details.
 
@@ -21,6 +21,10 @@ EXIT_INTERNAL_ERROR = 14
 EXIT_FILE_TOO_BIG = 15
 EXIT_SSL_FAILURE = 16
 EXIT_SSH_KEY_FAILURE = 17
+EXIT_CONNECTION_FAILED = 18
+EXIT_SSL_CERTIFICATE_VERIFY_FAILURE = 19
+EXIT_NO_DISPLAY = 20
+
 
 EXIT_STR = {
     EXIT_OK                     : "OK",
@@ -41,4 +45,7 @@ EXIT_STR = {
     EXIT_FILE_TOO_BIG           : "FILE_TOO_BIG",
     EXIT_SSL_FAILURE            : "SSL_FAILURE",
     EXIT_SSH_KEY_FAILURE        : "SSH_KEY_FAILURE",
-    }
\ No newline at end of file
+    EXIT_CONNECTION_FAILED      : "CONNECTION_FAILED",
+    EXIT_SSL_CERTIFICATE_VERIFY_FAILURE : "SSL_CERTIFICATE_VERIFY_FAILURE",
+    EXIT_NO_DISPLAY             : "NO_DISPLAY",
+    }
