@@ -18,7 +18,7 @@ gtk = import_gtk()
 
 APPLICATION_NAME = "Xpra"
 SITE_DOMAIN = "xpra.org"
-SITE_URL = "http://%s/" % SITE_DOMAIN
+SITE_URL = "https://%s/" % SITE_DOMAIN
 
 
 GPL2 = None
