@@ -241,8 +241,13 @@ class ClipboardStateInfoWindow(object):
 def main():
     from xpra.platform import program_context
     from xpra.log import enable_color
+    from xpra.platform.gui import init, set_default_icon
     with program_context("Clipboard-Test", "Clipboard Test Tool"):
         enable_color()
+
+        set_default_icon("clipboard.png")
+        init()
+
         ClipboardStateInfoWindow()
         gtk.main()
 
