@@ -458,7 +458,7 @@ def get_socket_options(sock, level, options):
             continue
         try:
             v = sock.getsockopt(level, opt)
-        except socket.error:
+        except (OSError, socket.error):
             log("sock.getsockopt(%i, %s)", level, k, exc_info=True)
             errs.append(k)
         else:
@@ -626,6 +626,6 @@ def log_new_connection(conn, socket_info=""):
         log.info("New %s connection received", socktype)
         log.info(" on '%s'", frominfo)
     else:
-        log.info("New %s connection received")
+        log.info("New %s connection received", socktype)
         if socket_info:
             log.info(" on %s", pretty_socket(socket_info))
