@@ -264,6 +264,9 @@ def is_X11():
         return True
 
 saved_env = os.environ.copy()
+def get_saved_env_var(var, default=None):
+    return _saved_env.get(var, default)
+
 def is_Wayland():
     return _is_Wayland(saved_env)
 
