@@ -44,6 +44,7 @@ notifylog = Logger("osx", "notify")
 
 OSX_FOCUS_WORKAROUND = envint("XPRA_OSX_FOCUS_WORKAROUND", 2000)
 SLEEP_HANDLER = envbool("XPRA_OSX_SLEEP_HANDLER", True)
+EVENT_LISTENER = envbool("XPRA_OSX_EVENT_LISTENER", True)
 OSX_WHEEL_MULTIPLIER = envint("XPRA_OSX_WHEEL_MULTIPLIER", 100)
 OSX_WHEEL_PRECISE_MULTIPLIER = envint("XPRA_OSX_WHEEL_PRECISE_MULTIPLIER", 1)
 WHEEL = envbool("XPRA_WHEEL", True)
@@ -656,10 +657,10 @@ class Delegate(NSObject):
     @objc.python_method
     def register_sleep_handlers(self):
         log("register_sleep_handlers()")
-        workspace          = NSWorkspace.sharedWorkspace()
-        notificationCenter = workspace.notificationCenter()
+        self.workspace          = NSWorkspace.sharedWorkspace()
+        self.notificationCenter = self.workspace.notificationCenter()
         def add_observer(fn, val):
-            notificationCenter.addObserver_selector_name_object_(self, fn, val, None)
+            self.notificationCenter.addObserver_selector_name_object_(self, fn, val, None)
         #NSWorkspaceWillPowerOffNotification
         add_observer(self.receiveSleepNotification_, NSWorkspaceWillSleepNotification)
         add_observer(self.receiveWakeNotification_, NSWorkspaceDidWakeNotification)
@@ -775,10 +776,11 @@ class ClientExtras(object):
         self.client = None
 
     def ready(self):
-        try:
-            self.setup_event_listener()
-        except:
-            log.error("Error setting up OSX event listener", exc_info=True)
+        if EVENT_LISTENER:
+            try:
+                self.setup_event_listener()
+            except:
+                log.error("Error setting up OSX event listener", exc_info=True)
 
     def setup_event_listener(self):
         log("setup_event_listener()")
@@ -812,21 +814,22 @@ class ClientExtras(object):
     def check_display(self):
         log("check_display()")
         try:
+            c = self.client
             asleep = None
             if not can_access_display():
                 asleep = True
             else:
                 did = CG.CGMainDisplayID()
                 log("check_display() CGMainDisplayID()=%#x", did)
-                if did and self.client:
+                if did and c:
                     asleep = bool(CG.CGDisplayIsAsleep(did))
                     log("check_display() CGDisplayIsAsleep(%#x)=%s", did, asleep)
-            if asleep is not None and self.display_is_asleep!=asleep:
+            if c and asleep is not None and self.display_is_asleep!=asleep:
                 self.display_is_asleep = asleep
                 if asleep:
-                    self.client.suspend()
+                    c.suspend()
                 else:
-                    self.client.resume()
+                    c.resume()
             return True
         except Exception:
             log.error("Error checking display sleep status", exc_info=True)
