@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 # This file is part of Xpra.
-# Copyright (C) 2013-2018 Antoine Martin <antoine@xpra.org>
+# Copyright (C) 2013-2020 Antoine Martin <antoine@xpra.org>
 # Xpra is released under the terms of the GNU GPL v2, or, at your option, any
 # later version. See the file COPYING for details.
 
@@ -8,10 +8,12 @@ import Quartz.CoreGraphics as CG    #@UnresolvedImport
 
 from xpra.util import envbool
 from xpra.os_util import memoryview_to_bytes, _buffer
+from xpra.scripts.config import InitExit
+from xpra.scripts.main import check_display
 from xpra.server.gtk_server_base import GTKServerBase
 from xpra.server.shadow.gtk_shadow_server_base import GTKShadowServerBase
 from xpra.platform.darwin.keyboard_config import KeyboardConfig
-from xpra.platform.darwin.gui import get_CG_imagewrapper, take_screenshot
+from xpra.platform.darwin.gui import get_CG_imagewrapper, take_screenshot, can_access_display
 from xpra.log import Logger
 
 log = Logger("shadow", "osx")
@@ -70,14 +72,14 @@ class ShadowServer(GTKShadowServerBase):
 
     def __init__(self):
         #sanity check:
+        check_display()
         image = CG.CGWindowListCreateImage(CG.CGRectInfinite,
                     CG.kCGWindowListOptionOnScreenOnly,
                     CG.kCGNullWindowID,
                     CG.kCGWindowImageDefault)
         if image is None:
-            from xpra.scripts.config import InitExit
             log("cannot grab test screenshot - maybe you need to run this command whilst logged in via the UI")
-            raise InitExit(1, "cannot grab pixels from the screen, make sure this command is launched from a GUI session")
+            raise InitExit(EXIT_FAILURE, "cannot grab pixels from the screen, make sure this command is launched from a GUI session")
         patch_picture_encode()
         self.refresh_count = 0
         self.refresh_rectangle_count = 0
