@@ -25,6 +25,11 @@ class DotXpra(object):
         #socket-dir is not used by the win32 shadow server
         pass
 
+
+    def norm_socket_paths(self, local_display_name):
+        return [self.socket_path(local_display_name)]
+
+
     def socket_path(self, local_display_name):
         return PIPE_PATH+PIPE_PREFIX+local_display_name.replace(":", "")
 
