@@ -8,8 +8,8 @@ import os
 import sys
 import struct
 
-from xpra.os_util import bytestostr, hexstr
-from xpra.util import iround, envbool, envint, csv, ellipsizer
+from xpra.os_util import bytestostr, hexstr, get_saved_env_var
+from xpra.util import iround, envbool, envint, csv, ellipsizer, first_time
 from xpra.os_util import is_unity, is_gnome, is_kde, is_Fedora, is_X11, is_Wayland
 from xpra.log import Logger
 
@@ -69,9 +69,6 @@ def gl_check():
     return None
 
 
-def get_native_system_tray_classes():
-    return []
-
 def get_wm_name():
     wm_name = os.environ.get("XDG_CURRENT_DESKTOP", "")
     if os.environ.get("XDG_SESSION_TYPE")=="wayland" or os.environ.get("GDK_BACKEND")=="wayland":
@@ -93,21 +90,35 @@ def get_wm_name():
     return wm_name
 
 def get_clipboard_native_class():
-    if is_Wayland():
+    if os.environ.get("GDK_BACKEND", "")!="x11" and is_Wayland():
         return None
     return "xpra.x11.gtk_x11.clipboard.X11Clipboard"
 
+def get_native_system_tray_classes():
+    c = [_try_load_appindicator()]
+    traylog("get_native_system_tray_classes()=%s (USE_NATIVE_TRAY=%s)", c, USE_NATIVE_TRAY)
+    return c
+
 def get_native_tray_classes():
     #could restrict to only DEs that have a broken system tray like "GNOME Shell"?
-    c = []
-    if USE_NATIVE_TRAY:
-        try:
-            from xpra.platform.xposix.appindicator_tray import AppindicatorTray
-            c.append(AppindicatorTray)
-        except (ImportError, ValueError):
-            traylog("cannot load appindicator tray", exc_info=True)
+    c = [_try_load_appindicator()]
+    traylog("get_native_tray_classes()=%s (USE_NATIVE_TRAY=%s)", c, USE_NATIVE_TRAY)
     return c
 
+def _try_load_appindicator():
+    try:
+        from xpra.platform.xposix.appindicator_tray import AppindicatorTray
+        return AppindicatorTray
+    except (ImportError, ValueError):
+        if first_time("no-appindicator"):
+             traylog("cannot load appindicator tray", exc_info=True)
+             traylog.warn("Warning: appindicator library not found")
+             traylog.warn(" you may want to install libappindicator")
+             if get_saved_env_var("XDG_CURRENT_DESKTOP", "").upper().find("GNOME")>=0:
+                 traylog.warn(" With gnome-shell, you may also need some extensions:")
+                 traylog.warn(" 'top icons plus' and / or 'appindicator'")
+    return None
+
 
 def get_native_notifier_classes():
     ncs = []
@@ -807,6 +818,15 @@ class ClientExtras(object):
             dbuslog.error(" %s", e)
             return
 
+        try:
+            import dbus
+            assert dbus
+        except ImportError as e:
+            dbuslog("setup_dbus_signals()", exc_info=True)
+            dbuslog.warn("Warning: cannot setup dbus signals")
+            dbuslog.warn(" %s", e)
+            return
+
         try:
             bus = init_system_bus()
             self.system_bus = bus
@@ -952,10 +972,12 @@ class ClientExtras(object):
 
 
     def _get_xsettings(self):
-        try:
-            return self._xsettings_watcher.get_settings()
-        except:
-            log.error("failed to get XSETTINGS", exc_info=True)
+        xw = self._xsettings_watcher
+        if xw:
+            try:
+                return self._xsettings_watcher.get_settings()
+            except:
+                log.error("failed to get XSETTINGS", exc_info=True)
         return None
 
     def _handle_xsettings_changed(self, *_args):
