@@ -29,6 +29,21 @@ if PYTHON3:
 else:
     from types import GeneratorType as generator    #@Reimport
 
+def check_xdg():
+    try:
+        from xdg.Menu import Menu, MenuEntry
+        assert Menu and MenuEntry
+        return True
+    except ImportError as e:
+        if first_time("load-xdg"):
+            log.warn("Warning: cannot load menu data")
+            log.warn(" %s", e)
+        return False
+    except SyntaxError as e:
+        if first_time("load-xdg"):
+            log.warn("Warning: cannot load menu data")
+            log.warn(" %s", e)
+        return False
 
 def isvalidtype(v):
     if isinstance(v, (list, tuple, generator)):
@@ -241,7 +256,9 @@ def load_xdg_menu(submenu):
             de = entry.DesktopEntry
             name = de.getName()
             try:
-                entries_data[name] = load_xdg_entry(de)
+                v = load_xdg_entry(de)
+                if v and name:
+                    entries_data[name] = v
             except Exception as e:
                 log("load_xdg_menu(%s)", submenu, exc_info=True)
                 log.error("Error loading desktop entry '%s':", name)
@@ -250,13 +267,15 @@ def load_xdg_menu(submenu):
 
 def remove_icons(menu_data):
     def noicondata(d):
-        return dict((k,v) for k,v in d.items() if k!="IconData")
+        return dict((k,v) for k,v in d.items() if k and v and k!="IconData")
     filt = {}
     for category, cdef in menu_data.items():
         fcdef = dict(cdef)
         entries = dict(fcdef.get("Entries", {}))
         for entry, edef in tuple(entries.items()):
-            entries[entry] = noicondata(edef)
+            nd = noicondata(edef)
+            if entry and nd:
+                entries[entry] = nd
         fcdef["Entries"] = entries
         filt[category] = fcdef
     return filt
@@ -270,6 +289,8 @@ def load_xdg_menu_data(force_reload=False):
     return xdg_menu_data
 
 def do_load_xdg_menu_data():
+    if not check_xdg():
+        return {}
     try:
         from xdg.Menu import parse, Menu, ParsingError
     except ImportError:
@@ -317,7 +338,9 @@ def do_load_xdg_menu_data():
         if isinstance(submenu, Menu) and submenu.Visible:
             name = submenu.getName()
             try:
-                menu_data[name] = load_xdg_menu(submenu)
+                v = load_xdg_menu(submenu)
+                if v and name:
+                    menu_data[name] = v
             except Exception as e:
                 log("load_xdg_menu_data()", exc_info=True)
                 log.error("Error loading submenu '%s':", name)
