@@ -138,8 +138,8 @@ def do_legacy_bool_parse(cmdline, optionname, newoptionname=None):
     yes = "--%s" % optionname
     if newoptionname is None:
         newoptionname = optionname
-    do_replace_option(cmdline, no, "--%s=no" % optionname)
-    do_replace_option(cmdline, yes, "--%s=yes" % optionname)
+    do_replace_option(cmdline, no, "--%s=no" % newoptionname)
+    do_replace_option(cmdline, yes, "--%s=yes" % newoptionname)
 
 def ignore_options(args, options):
     for x in options:
@@ -1305,8 +1305,8 @@ def validated_encodings(encodings):
         from xpra.codecs.codec_constants import PREFERED_ENCODING_ORDER
     except ImportError:
         return []
-    lower_encodings = [x.lower() for x in encodings]
-    validated = [x for x in PREFERED_ENCODING_ORDER if x.lower() in lower_encodings]
+    encodings = [x.lower() for x in encodings]+list(encodings)
+    validated = [x for x in PREFERED_ENCODING_ORDER if x in encodings]
     if not validated:
         raise InitException("no valid encodings specified")
     return validated
