@@ -1,5 +1,5 @@
 # This file is part of Xpra.
-# Copyright (C) 2013-2017 Antoine Martin <antoine@devloop.org.uk>
+# Copyright (C) 2013-2018 Antoine Martin <antoine@xpra.org>
 # Xpra is released under the terms of the GNU GPL v2, or, at your option, any
 # later version. See the file COPYING for details.
 
@@ -7,7 +7,7 @@
 
 import os.path
 
-from xpra.net.crypto import get_salt, choose_digest
+from xpra.net.digest import get_salt, choose_digest
 from xpra.os_util import strtobytes
 from xpra.server.auth.sys_auth_base import SysAuthenticator
 from xpra.log import Logger
@@ -24,11 +24,19 @@ def init(opts):
 
 class FileAuthenticatorBase(SysAuthenticator):
     def __init__(self, username, **kwargs):
-        SysAuthenticator.__init__(self, username)
-        filename = kwargs.get("filename", password_file)
-        if filename and not os.path.isabs(filename):
-            exec_cwd = kwargs.get("exec_cwd", os.getcwd())
-            filename = os.path.join(exec_cwd, filename)
+        password_files = [kwargs.pop("filename", None)]+list(password_file or [])
+        log("FileAuthenticatorBase password_files=%s", password_files)
+        filename = None
+        for filename in password_files:
+            if not filename:
+                continue
+            if not os.path.isabs(filename):
+                exec_cwd = kwargs.get("exec_cwd", os.getcwd())
+                filename = os.path.join(exec_cwd, filename)
+            if os.path.exists(filename):
+                break
+        log("FileAuthenticatorBase filename=%s", filename)
+        SysAuthenticator.__init__(self, username, **kwargs)
         self.password_filename = filename
         self.password_filedata = None
         self.password_filetime = None
@@ -45,6 +53,7 @@ class FileAuthenticatorBase(SysAuthenticator):
             return None
         self.salt = get_salt()
         self.digest = choose_digest(digests)
+        self.challenge_sent = True
         if not self.digest:
             return None
         return self.salt, self.digest
