@@ -117,10 +117,8 @@ class Authenticator(SysAuthenticator):
         from cryptography.hazmat.primitives.asymmetric import ec
         errors = OrderedDict()
         for origin, public_key in self.public_keys.items():
-            verifier = public_key.verifier(sig, ec.ECDSA(hashes.SHA256()))
-            verifier.update(param)
             try:
-                verifier.verify()
+                public_key.verify(sig, param, ec.ECDSA(hashes.SHA256()))
                 log("ECDSA SHA256 verification passed for '%s'", origin)
                 return True
             except Exception as e:
