@@ -1,24 +1,25 @@
 # -*- coding: utf-8 -*-
 # This file is part of Xpra.
-# Copyright (C) 2010-2018 Antoine Martin <antoine@devloop.org.uk>
+# Copyright (C) 2010-2019 Antoine Martin <antoine@xpra.org>
 # Xpra is released under the terms of the GNU GPL v2, or, at your option, any
 # later version. See the file COPYING for details.
 
-from xpra.log import Logger
-log = Logger("window", "encoding")
-
 from xpra.net import compression
 from xpra.codecs.loader import get_codec
 from xpra.util import envbool, first_time
 from xpra.codecs.rgb_transform import rgb_reformat
-from xpra.os_util import memoryview_to_bytes, strtobytes, monotonic_time
+from xpra.os_util import memoryview_to_bytes, bytestostr, monotonic_time
+from xpra.log import Logger
+
 #"pixels_to_bytes" gets patched up by the OSX shadow server
 pixels_to_bytes = memoryview_to_bytes
 try:
     from xpra.net.mmap_pipe import mmap_write
-except:
+except ImportError:
     mmap_write = None               #no mmap
 
+log = Logger("window", "encoding")
+
 WEBP_PILLOW = envbool("XPRA_WEBP_PILLOW", False)
 
 
@@ -29,7 +30,7 @@ def webp_encode(image, supports_transparency, quality, speed, content_type):
     #log("WEBP_PILLOW=%s, enc_webp=%s, stride=%s, pixel_format=%s", WEBP_PILLOW, enc_webp, stride, pixel_format)
     if not WEBP_PILLOW and enc_webp and stride>0 and stride%4==0 and pixel_format in ("BGRA", "BGRX", "RGBA", "RGBX"):
         #prefer Cython module:
-        cdata, client_options = enc_webp.compress(image, quality, speed, supports_transparency, content_type)
+        cdata, client_options = enc_webp.encode(image, quality, speed, supports_transparency, content_type)
         return "webp", compression.Compressed("webp", cdata), client_options, image.get_width(), image.get_height(), 0, 24
     #fallback using Pillow:
     enc_pillow = get_codec("enc_pillow")
@@ -44,25 +45,28 @@ def webp_encode(image, supports_transparency, quality, speed, content_type):
 
 
 def rgb_encode(coding, image, rgb_formats, supports_transparency, speed, rgb_zlib=True, rgb_lz4=True, rgb_lzo=False):
-    pixel_format = strtobytes(image.get_pixel_format())
-    #log("rgb_encode%s pixel_format=%s, rgb_formats=%s", (coding, image, rgb_formats, supports_transparency, speed, rgb_zlib, rgb_lz4), pixel_format, rgb_formats)
+    pixel_format = bytestostr(image.get_pixel_format())
+    #log("rgb_encode%s pixel_format=%s, rgb_formats=%s",
+    #    (coding, image, rgb_formats, supports_transparency, speed, rgb_zlib, rgb_lz4), pixel_format, rgb_formats)
     if pixel_format not in rgb_formats:
         log("rgb_encode reformatting because %s not in %s", pixel_format, rgb_formats)
         if not rgb_reformat(image, rgb_formats, supports_transparency):
             raise Exception("cannot find compatible rgb format to use for %s! (supported: %s)" % (pixel_format, rgb_formats))
         #get the new format:
-        pixel_format = strtobytes(image.get_pixel_format())
+        pixel_format = bytestostr(image.get_pixel_format())
         #switch encoding if necessary:
-        if len(pixel_format)==4 and coding=="rgb24":
+        if len(pixel_format)==4:
             coding = "rgb32"
-        elif len(pixel_format)==3 and coding=="rgb32":
+        elif len(pixel_format)==3:
             coding = "rgb24"
+        else:
+            raise Exception("invalid pixel format %s" % pixel_format)
+    else:
+        #we may still want to re-stride:
+        image.may_restride()
     #always tell client which pixel format we are sending:
     options = {"rgb_format" : pixel_format}
 
-    #we may want to re-stride:
-    image.may_restride()
-
     #compress here and return a wrapper so network code knows it is already zlib compressed:
     pixels = image.get_pixels()
     assert pixels, "failed to get pixels from %s" % image
@@ -111,11 +115,12 @@ def rgb_encode(coding, image, rgb_formats, supports_transparency, speed, rgb_zli
         #and even if we could, the image containing those pixels may be freed by the time we get to the encoder
         algo = "not"
         cwrapper = compression.Compressed(coding, pixels_to_bytes(pixels), True)
-    if pixel_format.upper().find(b"A")>=0 or pixel_format.upper().find(b"X")>=0:
+    if pixel_format.find("A")>=0 or pixel_format.find("X")>=0:
         bpp = 32
     else:
         bpp = 24
-    log("rgb_encode using level=%s for %5i pixels at %3i speed, %s compressed %4sx%-4s in %s/%s: %5s bytes down to %5s", level, l, speed, algo, image.get_width(), image.get_height(), coding, pixel_format, len(pixels), len(cwrapper.data))
+    log("rgb_encode using level=%s for %5i bytes at %3i speed, %s compressed %4sx%-4s in %s/%s: %5s bytes down to %5s",
+        level, l, speed, algo, image.get_width(), image.get_height(), coding, pixel_format, len(pixels), len(cwrapper.data))
     #wrap it using "Compressed" so the network layer receiving it
     #won't decompress it (leave it to the client's draw thread)
     return coding, cwrapper, options, width, height, stride, bpp
