@@ -1,14 +1,11 @@
 # This file is part of Xpra.
-# Copyright (C) 2017 Antoine Martin <antoine@devloop.org.uk>
+# Copyright (C) 2017 Antoine Martin <antoine@xpra.org>
 # Xpra is released under the terms of the GNU GPL v2, or, at your option, any
 # later version. See the file COPYING for details.
 
 import struct
 from socket import error as socket_error
 
-from xpra.log import Logger
-log = Logger("network", "protocol", "rfb")
-
 from xpra.os_util import Queue, hexstr, strtobytes
 from xpra.util import repr_ellipsized, envint, nonl
 from xpra.make_thread import make_thread, start_thread
@@ -16,6 +13,9 @@ from xpra.net.protocol import force_flush_queue, exit_queue
 from xpra.net.common import ConnectionClosedException          #@UndefinedVariable (pydev false positive)
 from xpra.net.bytestreams import ABORT
 from xpra.server.rfb.rfb_const import RFBClientMessage, RFBAuth, PIXEL_FORMAT
+from xpra.log import Logger
+
+log = Logger("network", "protocol", "rfb")
 
 READ_BUFFER_SIZE = envint("XPRA_READ_BUFFER_SIZE", 65536)
 
@@ -53,6 +53,10 @@ class RFBProtocol(object):
         self._read_thread = make_thread(self._read_thread_loop, "read", daemon=True)
 
 
+    def is_closed(self):
+        return self._closed
+
+
     def send_protocol_handshake(self):
         self.send(b"RFB 003.008\n")
 
@@ -68,7 +72,8 @@ class RFBProtocol(object):
             return 0
         #ie: packet==b'RFB 003.008\n'
         self._protocol_version = tuple(int(x) for x in packet[4:11].split(b"."))
-        log.info("RFB version %s connection from %s", ".".join(str(x) for x in self._protocol_version), self._conn.target)
+        log.info("RFB version %s connection from %s",
+                 ".".join(str(x) for x in self._protocol_version), self._conn.target)
         if self._protocol_version!=(3, 8):
             msg = "unsupported protocol version"
             log.error("Error: %s", msg)
@@ -91,7 +96,7 @@ class RFBProtocol(object):
         log("parse_security_handshake(%s)", hexstr(packet))
         try:
             auth = struct.unpack(b"B", packet)[0]
-        except:
+        except struct.error:
             self._internal_error(packet, "cannot parse security handshake response '%s'" % hexstr(packet))
             return 0
         auth_str = RFBAuth.AUTH_STR.get(auth, auth)
@@ -145,7 +150,10 @@ class RFBProtocol(object):
         #send ClientInit
         self._packet_parser = self._parse_rfb
         w, h, bpp, depth, bigendian, truecolor, rmax, gmax, bmax, rshift, bshift, gshift = self._get_rfb_pixelformat()
-        packet =  struct.pack(b"!HH"+PIXEL_FORMAT+b"I", w, h, bpp, depth, bigendian, truecolor, rmax, gmax, bmax, rshift, bshift, gshift, 0, 0, 0, len(self.session_name))+strtobytes(self.session_name)
+        packet =  struct.pack(b"!HH"+PIXEL_FORMAT+b"I",
+                              w, h, bpp, depth, bigendian, truecolor,
+                              rmax, gmax, bmax, rshift, bshift, gshift,
+                              0, 0, 0, len(self.session_name))+strtobytes(self.session_name)
         self.send(packet)
         self._process_packet_cb(self, [b"authenticated"])
         return 1
@@ -153,7 +161,7 @@ class RFBProtocol(object):
     def _parse_rfb(self, packet):
         try:
             ptype = ord(packet[0])
-        except:
+        except TypeError:
             ptype = packet[0]
         packet_type = RFBClientMessage.PACKET_TYPE_STR.get(ptype)
         if not packet_type:
@@ -196,7 +204,10 @@ class RFBProtocol(object):
         return "RFBProtocol(%s)" % self._conn
 
     def get_threads(self):
-        return  [x for x in [self._write_thread, self._read_thread] if x is not None]
+        return tuple(x for x in (
+            self._write_thread,
+            self._read_thread,
+            ) if x is not None)
 
 
     def get_info(self, *_args):
@@ -357,8 +368,8 @@ class RFBProtocol(object):
             try:
                 log("RFBProtocol.close() calling %s", c.close)
                 c.close()
-            except:
-                log.error("error closing %s", self._conn, exc_info=True)
+            except IOError:
+                log.error("Error closing %s", self._conn, exc_info=True)
             self._conn = None
         self.terminate_queue_threads()
         self._process_packet_cb(self, [RFBProtocol.CONNECTION_LOST])
