@@ -406,9 +406,8 @@ class ServerBase(ServerBaseClass):
         except Exception as e:
             #log exception but don't disclose internal details to the client
             p = ss.protocol
-            log("_process_hello_ui%s", (ss, c, auth_caps, send_ui, share_count), exc_info=True)
-            log.error("Error: processing new connection from %s:", p or ss)
-            log.error(" %s", e)
+            log("_process_hello_ui%s", (ss, c, auth_caps, send_ui, share_count))
+            log.error("Error: processing new connection from %s:", p or ss, exc_info=True)
             if p:
                 self.disconnect_client(p, SERVER_ERROR, "error accepting new connection")
 
@@ -673,8 +672,12 @@ class ServerBase(ServerBaseClass):
                 if v is None:
                     log.warn("removing invalid None property for %s", k)
                     continue
-                k = strtobytes(k)
-                if not k.startswith(b"encoding"):
+                k = bytestostr(k)
+                if k=="event":
+                    #event is used as a workaround in _process_map_window,
+                    #it isn't a real client property and should not be stored:
+                    continue
+                if not k.startswith("encoding"):
                     ncp[k] = v
             if ncp:
                 log("set_client_properties updating window %s of source %s with %s", wid, ss.uuid, ncp)
