@@ -251,6 +251,7 @@ class ServerCore(object):
         self.server_idle_timeout = 0
         self.server_idle_timer = None
         self.bandwidth_limit = 0
+        self.readonly = False
 
         self.init_uuid()
         sanity_checks()
@@ -367,14 +368,14 @@ class ServerCore(object):
             if w and w.is_alive():
                 #wait up to 1 second for the worker thread to exit
                 try:
-                    w.wait(1)
+                    w.join(1)
                 except:
                     pass
                 if w.is_alive():
                     #still alive, force stop:
                     stop_worker(True)
                     try:
-                        w.wait(1)
+                        w.join(1)
                     except:
                         pass
             self.quit(upgrading)
@@ -1345,8 +1346,17 @@ class ServerCore(object):
         return {
             "/Status"       : self.http_status_request,
             "/Info"         : self.http_info_request,
+            "/Sessions"     : self.http_404,
+            "/Displays"     : self.http_404,
+            "/Menu"         : self.http_404,
+            "/MenuIcon"     : self.http_404,
+            "/DesktopMenu"  : self.http_404,
+            "/DesktopMenuIcon" : self.http_404,
             }
 
+    def http_404(self, handler):
+        self.send_http_response(handler)
+
     def start_http_socket(self, socktype, conn, is_ssl=False, peek_data=""):
         frominfo = pretty_socket(conn.remote)
         line1 = b""
@@ -1420,7 +1430,7 @@ class ServerCore(object):
     def http_status_request(self, handler):
         return self.send_http_response(handler, "ready")
 
-    def send_http_response(self, handler, content, content_type="text/plain"):
+    def send_http_response(self, handler, content=None, content_type="text/plain"):
         if content is None:
             handler.send_response(404)
         else:
@@ -1622,7 +1632,7 @@ class ServerCore(object):
             return
 
         log("process_hello: capabilities=%s", capabilities)
-        if c.boolget("version_request"):
+        if c.strget("request")=="version" or c.boolget("version_request"):
             self.send_version_info(proto, c.boolget("full-version-request"))
             return
         #verify version:
