@@ -139,8 +139,11 @@ class SSHServer(paramiko.ServerInterface):
             cmd = shlex.split(command.decode("utf8"))
         except UnicodeDecodeError:
             cmd = shlex.split(bytestostr(command))
-        if cmd[0] in ("type", "which") and len(cmd)==2:
-            xpra_cmd = cmd[1]   #ie: $XDG_RUNTIME_DIR/xpra/run-xpra or "xpra"
+        if cmd[0]=="command" and len(cmd)==1:
+            channel.send_exit_status(0)
+            return True
+        if cmd[0] in ("type", "which", "command") and len(cmd)==2:
+            xpra_cmd = cmd[-1]   #ie: $XDG_RUNTIME_DIR/xpra/run-xpra or "xpra"
             if not POSIX:
                 assert WIN32
                 #we can't execute "type" or "which" on win32,
