@@ -1,21 +1,28 @@
 #!/usr/bin/env python
 # This file is part of Xpra.
-# Copyright (C) 2010-2017 Antoine Martin <antoine@devloop.org.uk>
+# Copyright (C) 2010-2017 Antoine Martin <antoine@xpra.org>
 # Xpra is released under the terms of the GNU GPL v2, or, at your option, any
 # later version. See the file COPYING for details.
 
-import os
 import sys
+import os.path
 
 from xpra.os_util import SIGNAMES, Queue, monotonic_time
-from xpra.util import csv, envint, envbool, AtomicInteger
+from xpra.util import csv, envint, envbool, envfloat, AtomicInteger
 from xpra.sound.sound_pipeline import SoundPipeline
 from xpra.gtk_common.gobject_util import n_arg_signal, gobject
-from xpra.sound.gstreamer_util import get_source_plugins, plugin_str, get_encoder_elements, get_encoder_default_options, normv, get_encoders, get_queue_time, has_plugins, \
-                                MP3, CODEC_ORDER, MUXER_DEFAULT_OPTIONS, ENCODER_NEEDS_AUDIOCONVERT, SOURCE_NEEDS_AUDIOCONVERT, MS_TO_NS, GST_QUEUE_LEAK_DOWNSTREAM
+from xpra.sound.gstreamer_util import (
+    get_source_plugins, plugin_str, get_encoder_elements,
+    get_encoder_default_options, normv,
+    get_encoders, get_queue_time, has_plugins,
+    MP3, CODEC_ORDER, MUXER_DEFAULT_OPTIONS, ENCODER_NEEDS_AUDIOCONVERT,
+    SOURCE_NEEDS_AUDIOCONVERT, ENCODER_CANNOT_USE_CUTTER, CUTTER_NEEDS_CONVERT,
+    CUTTER_NEEDS_RESAMPLE, MS_TO_NS, GST_QUEUE_LEAK_DOWNSTREAM,
+    )
 from xpra.net.compression import compressed_wrapper
 from xpra.scripts.config import InitExit
 from xpra.log import Logger
+
 log = Logger("sound")
 gstlog = Logger("gstreamer")
 
@@ -26,7 +33,11 @@ SOURCE_QUEUE_TIME = get_queue_time(50, "SOURCE_")
 BUFFER_TIME = envint("XPRA_SOUND_SOURCE_BUFFER_TIME", 0)    #ie: 64
 LATENCY_TIME = envint("XPRA_SOUND_SOURCE_LATENCY_TIME", 0)  #ie: 32
 BUNDLE_METADATA = envbool("XPRA_SOUND_BUNDLE_METADATA", True)
+LOG_CUTTER = envbool("XPRA_SOUND_LOG_CUTTER", False)
 SAVE_TO_FILE = os.environ.get("XPRA_SAVE_TO_FILE")
+CUTTER_THRESHOLD = envfloat("XPRA_CUTTER_THRESHOLD", "0.0001")
+CUTTER_PRE_LENGTH = envint("XPRA_CUTTER_PRE_LENGTH", 100)
+CUTTER_RUN_LENGTH = envint("XPRA_CUTTER_RUN_LENGTH", 1000)
 
 generation = AtomicInteger()
 
@@ -38,7 +49,7 @@ class SoundSource(SoundPipeline):
         "new-buffer"    : n_arg_signal(3),
         })
 
-    def __init__(self, src_type=None, src_options={}, codecs=get_encoders(), codec_options={}, volume=1.0):
+    def __init__(self, src_type=None, src_options=None, codecs=(), codec_options=None, volume=1.0):
         if not src_type:
             try:
                 from xpra.sound.pulseaudio.pulseaudio_util import get_pa_device_options
@@ -48,7 +59,7 @@ class SoundSource(SoundPipeline):
                 log.warn("Warning: pulseaudio is not available!")
                 log.warn(" %s", e)
                 monitor_devices = []
-            if len(monitor_devices)==0:
+            if not monitor_devices:
                 log.warn("could not detect any pulseaudio monitor devices")
                 log.warn(" a test source will be used instead")
                 src_type = "audiotestsrc"
@@ -76,12 +87,16 @@ class SoundSource(SoundPipeline):
         self.src = None
         self.src_type = src_type
         self.timestamp = None
+        self.min_timestamp = 0
+        self.max_timestamp = 0
         self.pending_metadata = []
         self.buffer_latency = True
         self.jitter_queue = None
         self.file = None
         self.container_format = (fmt or "").replace("mux", "").replace("pay", "")
         self.stream_compressor = stream_compressor
+        if src_options is None:
+            src_options = {}
         src_options["name"] = "src"
         source_str = plugin_str(src_type, src_options)
         #FIXME: this is ugly and relies on the fact that we don't pass any codec options to work!
@@ -100,6 +115,13 @@ class SoundSource(SoundPipeline):
             pipeline_els += [" ".join(queue_el)]
         if encoder in ENCODER_NEEDS_AUDIOCONVERT or src_type in SOURCE_NEEDS_AUDIOCONVERT:
             pipeline_els += ["audioconvert"]
+        if CUTTER_THRESHOLD>0 and encoder not in ENCODER_CANNOT_USE_CUTTER and not fmt:
+            pipeline_els.append("cutter threshold=%.4f run-length=%i pre-length=%i leaky=false name=cutter" % (
+                CUTTER_THRESHOLD, CUTTER_RUN_LENGTH*MS_TO_NS, CUTTER_PRE_LENGTH*MS_TO_NS))
+            if encoder in CUTTER_NEEDS_CONVERT:
+                pipeline_els.append("audioconvert")
+            if encoder in CUTTER_NEEDS_RESAMPLE:
+                pipeline_els.append("audioresample")
         pipeline_els.append("volume name=volume volume=%s" % volume)
         if encoder:
             encoder_str = plugin_str(encoder, codec_options or get_encoder_default_options(encoder))
@@ -140,7 +162,8 @@ class SoundSource(SoundPipeline):
             if BUFFER_TIME<LATENCY_TIME:
                 log.warn("Warning: latency (%ims) must be lower than the buffer time (%ims)", LATENCY_TIME, BUFFER_TIME)
             else:
-                log("latency tuning for %s, will try to set buffer-time=%i, latency-time=%i", src_type, BUFFER_TIME, LATENCY_TIME)
+                log("latency tuning for %s, will try to set buffer-time=%i, latency-time=%i",
+                    src_type, BUFFER_TIME, LATENCY_TIME)
                 def settime(attr, v):
                     try:
                         cval = self.src.get_property(attr)
@@ -180,6 +203,9 @@ class SoundSource(SoundPipeline):
         info = SoundPipeline.get_info(self)
         if self.queue:
             info["queue"] = {"cur" : self.queue.get_property("current-level-time")//MS_TO_NS}
+        if CUTTER_THRESHOLD>0 and (self.min_timestamp or self.max_timestamp):
+            info["cutter.min-timestamp"] = self.min_timestamp
+            info["cutter.max-timestamp"] = self.max_timestamp
         if self.buffer_latency:
             for x in ("actual-buffer-time", "actual-latency-time"):
                 v = self.src.get_property(x)
@@ -188,21 +214,44 @@ class SoundSource(SoundPipeline):
         return info
 
 
-    def on_new_preroll(self, appsink):
+    def do_parse_element_message(self, _message, name, props=None):
+        if name=="cutter" and props:
+            above = props.get("above")
+            ts = props.get("timestamp", 0)
+            if above is False:
+                self.max_timestamp = ts
+                self.min_timestamp = 0
+            elif above is True:
+                self.max_timestamp = 0
+                self.min_timestamp = ts
+            if LOG_CUTTER:
+                l = gstlog.info
+            else:
+                l = gstlog
+            l("cutter message, above=%s, min-timestamp=%s, max-timestamp=%s",
+              above, self.min_timestamp, self.max_timestamp)
+
+
+    def on_new_preroll(self, _appsink):
         gstlog('new preroll')
         return 0
 
-    def on_new_sample(self, bus):
+    def on_new_sample(self, _bus):
         #Gst 1.0
         sample = self.sink.emit("pull-sample")
         return self.emit_buffer(sample)
 
     def emit_buffer(self, sample):
         buf = sample.get_buffer()
-        #info = sample.get_info()
+        pts = normv(buf.pts)
+        if self.min_timestamp>0 and pts<self.min_timestamp:
+            gstlog("cutter: skipping buffer with pts=%s (min-timestamp=%s)", pts, self.min_timestamp)
+            return 0
+        if self.max_timestamp>0 and pts>self.max_timestamp:
+            gstlog("cutter: skipping buffer with pts=%s (max-timestamp=%s)", pts, self.max_timestamp)
+            return 0
         size = buf.get_size()
         data = buf.extract_dup(0, size)
-        pts = normv(buf.pts)
         duration = normv(buf.duration)
         metadata = {
             "timestamp"  : pts,
@@ -213,7 +262,8 @@ class SoundSource(SoundPipeline):
             ts = (pts+delta)//1000000           #ns to ms
             now = monotonic_time()
             latency = int(1000*now)-ts
-            #log.info("emit_buffer: delta=%i, pts=%i, ts=%s, time=%s, latency=%ims", delta, pts, ts, now, (latency//1000000))
+            #log.info("emit_buffer: delta=%i, pts=%i, ts=%s, time=%s, latency=%ims",
+            #    delta, pts, ts, now, (latency//1000000))
             ts_info = {
                 "ts"        : ts,
                 "latency"   : latency,
@@ -225,15 +275,20 @@ class SoundSource(SoundPipeline):
             return 0
         return self._emit_buffer(data, metadata)
 
-    def _emit_buffer(self, data, metadata={}):
+    def _emit_buffer(self, data, metadata):
         if self.stream_compressor and data:
-            cdata = compressed_wrapper("sound", data, level=9, zlib=False, lz4=(self.stream_compressor=="lz4"), lzo=(self.stream_compressor=="lzo"), can_inline=True)
+            cdata = compressed_wrapper("sound", data, level=9,
+                                       zlib=False,
+                                       lz4=self.stream_compressor=="lz4",
+                                       lzo=self.stream_compressor=="lzo",
+                                       can_inline=True)
             if len(cdata)<len(data)*90//100:
                 log("compressed using %s from %i bytes down to %i bytes", self.stream_compressor, len(data), len(cdata))
                 metadata["compress"] = self.stream_compressor
                 data = cdata
             else:
-                log("skipped inefficient %s stream compression: %i bytes down to %i bytes", self.stream_compressor, len(data), len(cdata))
+                log("skipped inefficient %s stream compression: %i bytes down to %i bytes",
+                    self.stream_compressor, len(data), len(cdata))
         f = self.file
         if f:
             for x in self.pending_metadata:
@@ -271,7 +326,7 @@ class SoundSource(SoundPipeline):
                 capd = {}
                 for k in cap.keys():
                     v = cap[k]
-                    if type(v) in (str, int):
+                    if isinstance(v, (str, int)):
                         capd[k] = cap[k]
                     elif k not in self.skipped_caps:
                         log("skipping %s cap key %s=%s of type %s", name, k, v, type(v))
@@ -287,7 +342,7 @@ class SoundSource(SoundPipeline):
             d,m = self.jitter_queue.get(False)
             self.do_emit_buffer(d, m)
 
-    def do_emit_buffer(self, data, metadata={}):
+    def do_emit_buffer(self, data, metadata):
         self.inc_buffer_count()
         self.inc_byte_count(len(data))
         for x in self.pending_metadata:
@@ -306,7 +361,6 @@ gobject.type_register(SoundSource)
 def main():
     from xpra.platform import program_context
     with program_context("Xpra-Sound-Source"):
-        import os.path
         if "-v" in sys.argv:
             log.enable_debug()
             sys.argv.remove("-v")
@@ -357,7 +411,7 @@ def main():
             f = open(filename, "wb")
         ss = SoundSource(codecs=[codec])
         lock = Lock()
-        def new_buffer(ss, data, metadata, packet_metadata):
+        def new_buffer(_soundsource, data, metadata, packet_metadata):
             log.info("new buffer: %s bytes (%s), metadata=%s", len(data), type(data), metadata)
             with lock:
                 if f:
@@ -374,17 +428,15 @@ def main():
         ss.start()
 
         import signal
-        def deadly_signal(sig, frame):
+        def deadly_signal(sig, _frame):
             log.warn("got deadly signal %s", SIGNAMES.get(sig, sig))
             glib.idle_add(ss.stop)
             glib.idle_add(glib_mainloop.quit)
-            def force_quit(sig, frame):
+            def force_quit(_sig, _frame):
                 sys.exit()
             signal.signal(signal.SIGINT, force_quit)
             signal.signal(signal.SIGTERM, force_quit)
-        from xpra.gtk_common.gobject_compat import is_gtk3
-        if not is_gtk3():
-            signal.signal(signal.SIGINT, deadly_signal)
+        signal.signal(signal.SIGINT, deadly_signal)
         signal.signal(signal.SIGTERM, deadly_signal)
 
         try:
