@@ -1,5 +1,5 @@
 # This file is part of Xpra.
-# Copyright (C) 2017 Antoine Martin <antoine@devloop.org.uk>
+# Copyright (C) 2017 Antoine Martin <antoine@xpra.org>
 # Xpra is released under the terms of the GNU GPL v2, or, at your option, any
 # later version. See the file COPYING for details.
 
@@ -24,7 +24,7 @@ class X11Event(object):
     def __repr__(self):
         d = {}
         for k,v in self.__dict__.items():
-            if k=="name":
+            if k in ("name", "display", "type"):
                 continue
             elif k=="serial":
                 d[k] = "%#x" % v
