@@ -330,10 +330,9 @@ class ClipboardProxy(ClipboardProxyCore, gobject.GObject):
         data = X11Window.XGetWindowProperty(xid, "WM_NAME", "STRING")
         if data:
             return data.decode("latin1")
-        data = X11Window.XGetWindowProperty(xid, "_NET_WM_NAME", "STRING")
+        data = X11Window.XGetWindowProperty(xid, "_NET_WM_NAME", "UTF8_STRING")
         if data:
             return data.decode("utf8")
-        xid = X11Window.getParent(xid)
         return None
 
     def get_wininfo(self, xid):
