@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 # This file is part of Xpra.
 # Copyright (C) 2011 Serviware (Arthur Huillet, <ahuillet@serviware.com>)
-# Copyright (C) 2010-2018 Antoine Martin <antoine@xpra.org>
+# Copyright (C) 2010-2021 Antoine Martin <antoine@xpra.org>
 # Copyright (C) 2008 Nathaniel Smith <njs@pobox.com>
 # Xpra is released under the terms of the GNU GPL v2, or, at your option, any
 # later version. See the file COPYING for details.
@@ -93,8 +93,11 @@ class X11ServerBase(X11ServerCore):
             elif self._upgrading:
                 log.info("upgrading: not cleaning up Xvfb")
             else:
+                from xpra.scripts.server import add_cleanup
                 from xpra.x11.vfb_util import kill_xvfb
-                kill_xvfb(self.display_pid)
+                def do_kill_display():
+                    kill_xvfb(self.display_pid)
+                add_cleanup(do_kill_display)
 
 
     def do_cleanup(self):
