@@ -93,9 +93,11 @@ def do_set_keymap(xkbmap_layout, xkbmap_variant, xkbmap_options,
             log.info("setting keymap: %s",
                      csv("%s=%s" % (std(k), std(v)) for k,v in xkbmap_query_struct.items()
                          if k in ("rules", "model", "layout") and v))
-            safe_setxkbmap(rules, model, layout, variant, options)
+            if safe_setxkbmap(rules, model, layout, variant, options):
+                return
         else:
-            safe_setxkbmap(rules, model, "", "", "")
+            if safe_setxkbmap(rules, model, "", "", ""):
+                return
     if xkbmap_print:
         #TODO: this is no longer used with any client, remove it
         log("do_set_keymap using xkbmap_print")
@@ -120,7 +122,7 @@ def safe_setxkbmap(rules, model, layout, variant, options):
     #(we execute the options separately in case that fails..)
     try:
         X11Keyboard.setxkbmap(rules, model, layout, variant, options)
-        return
+        return True
     except Exception:
         log("safe_setxkbmap%s", (rules, model, layout, variant, options), exc_info=True)
         log.warn("Warning: failed to set exact keymap,")
@@ -130,10 +132,12 @@ def safe_setxkbmap(rules, model, layout, variant, options):
         #try again with no options:
         try:
             X11Keyboard.setxkbmap(rules, model, layout, variant, "")
+            return True
         except Exception:
             log("setxkbmap", exc_info=True)
             log.error("Error: failed to set exact keymap")
             log.error(" even without applying any options..")
+    return False
 
 
 ################################################################################
